<?php

namespace Tricks\Dashboard;

use Laravel\Nova\Card;

class Dashboard extends Card
{
    public $width = 'full';

    public function component(): string
    {
        return 'dashboard';
    }

    public function __construct($component = null)
    {
        parent::__construct($component);

        $this->withMeta(['elements' => config('nova-dashboard.elements') ?? null]);
    }
}
